==> ktp-accounts-kcm-0.7.80.tar.bz2: ktp-accounts-kcm-0.7.80/plugins/sipe/ktpaccountskcm_plugin_sipe.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the sipe connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći sipe menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Sipe.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení sipe.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen sipe.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Sipe-Verbindungsverwaltung verwenden.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones sipe.
Comment[fi]=Sipe-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[hu]=Egyedi beállítófelület a sipe kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Sipe.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Sipe.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av sipe tilkoblingsbehandler.
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Sipe verbindingenbeheerder gebruiken.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Sipe.
Comment[pt_BR]=Interface de configuração de contas personalizadas usando o gerenciador de conexões Sipe.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Sipe.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Sipe.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Сајп.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Сајп.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze SIPE.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze SIPE.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Sipe.
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями sipe.
Comment[x-test]=xxCustom account configuration user interface for accounts using the sipe connection manager.xx
Comment[zh_TW]=對使用 sipe 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Sipe Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Sipe
Name[ca]=Interfície d'usuari de configuració de compte de Sipe
Name[cs]=Uživatelské rozhraní nastavení účtu Sipe
Name[da]=Brugerflade til konfiguration af sipe-konto
Name[de]=Benutzeroberfläche zur Einrichtung von Sipe-Zugängen
Name[es]=Interfaz de configuración de cuentas Sipe
Name[fi]=Sipe-tilinmäärityksen käyttöliittymä
Name[hu]=Sipe azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Sipe
Name[it]=Interfaccia utente di configurazione account Sipe
Name[nb]=Brukerflate for å sette opp Sipe-konto
Name[nl]=Gebruikersinterface voor Sipe accountconfiguratie
Name[pt]=Interface de Configuração de Contas do Sipe
Name[pt_BR]=Interface de configuração de contas do Sipe
Name[sk]=Používateľské rozhranie konfigurácie účtu Sipe
Name[sl]=Uporabniški vmesnik za nastavitev računov Sipe
Name[sr]=Корисничко сучеље за подешавање налога под Сајпом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Сајпом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod SIPE‑om
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod SIPE‑om
Name[sv]=Användargränssnitt för inställning av Sipe-konton
Name[uk]=Інтерфейс користувача для налаштовування sipe
Name[x-test]=xxSipe Account Configuration User Interfacexx
Name[zh_TW]=Sipe 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_sipe
X-KDE-PluginInfo-Author=Maksim Melnikau
X-KDE-PluginInfo-Email=maxposedon@gmail.com
X-KDE-PluginInfo-Name=sipe
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm-0.8.0.tar.bz2: ktp-accounts-kcm-0.8.0/plugins/sipe/ktpaccountskcm_plugin_sipe.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the sipe connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći sipe menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Sipe.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení sipe.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen sipe.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Sipe-Verbindungsverwaltung verwenden.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones sipe.
Comment[fi]=Sipe-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[hu]=Egyedi beállítófelület a sipe kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Sipe.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Sipe.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av sipe tilkoblingsbehandler.
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Sipe verbindingenbeheerder gebruiken.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Sipe.
Comment[pt_BR]=Interface de configuração de contas personalizadas usando o gerenciador de conexões Sipe.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Sipe.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Sipe.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Сајп.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Сајп.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze SIPE.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze SIPE.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Sipe.
Comment[tr]=Sipe bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями sipe.
Comment[x-test]=xxCustom account configuration user interface for accounts using the sipe connection manager.xx
Comment[zh_TW]=對使用 sipe 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Sipe Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Sipe
Name[ca]=Interfície d'usuari de configuració de compte de Sipe
Name[cs]=Uživatelské rozhraní nastavení účtu Sipe
Name[da]=Brugerflade til konfiguration af sipe-konto
Name[de]=Benutzeroberfläche zur Einrichtung von Sipe-Zugängen
Name[es]=Interfaz de configuración de cuentas Sipe
Name[fi]=Sipe-tilinmäärityksen käyttöliittymä
Name[hu]=Sipe azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Sipe
Name[it]=Interfaccia utente di configurazione account Sipe
Name[nb]=Brukerflate for å sette opp Sipe-konto
Name[nl]=Gebruikersinterface voor Sipe accountconfiguratie
Name[pt]=Interface de Configuração de Contas do Sipe
Name[pt_BR]=Interface de configuração de contas do Sipe
Name[sk]=Používateľské rozhranie konfigurácie účtu Sipe
Name[sl]=Uporabniški vmesnik za nastavitev računov Sipe
Name[sr]=Корисничко сучеље за подешавање налога под Сајпом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Сајпом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod SIPE‑om
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod SIPE‑om
Name[sv]=Användargränssnitt för inställning av Sipe-konton
Name[tr]=Sipe Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштовування sipe
Name[x-test]=xxSipe Account Configuration User Interfacexx
Name[zh_TW]=Sipe 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_sipe
X-KDE-PluginInfo-Author=Maksim Melnikau
X-KDE-PluginInfo-Email=maxposedon@gmail.com
X-KDE-PluginInfo-Name=sipe
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
